require 'helper'

describe 'TFTP::Protocol' do
  context "when creating packets" do
    describe 'TFTP::Protocol::ACK.create' do

      let(:packet) { TFTP::Protocol::ACK.new }

      context "when not providing a block number" do
        it { packet.create.to_binary_s.should == "\x00\x04\x00\x00" }
      end

      context "when providing a valid block number, e.g., 1" do
        it { packet.create({:block_num => 1}).to_binary_s.should == "\x00\x04\x00\x01" }
      end

      context "when not providing a valid block number, e.g. -1" do
        it { expect { packet.create({:block_num => -1}) }.to raise_error(RuntimeError, 'Block nums must begin with 1 and increase by one for each new block of data.') }
      end

    end

    describe 'TFTP::Protocol::WRQ.create' do

      let(:packet) { TFTP::Protocol::WRQ.new }

      context "when not providing a filename" do
        it { expect { packet.create }.to raise_error(RuntimeError, 'All RRQ/WRQ packets are required to have a filename.') }
      end

      context "when not providing a mode" do
        it { packet.create({:filename => "test.txt"}).to_binary_s.should == "\x00\x02test.txt\x00octet\x00" }
      end

      context "when providing an unsupported mode" do
        it { expect { packet.create({:filename => "test.txt", :mode => "badmode"})}.to raise_error(RuntimeError, 'Octet is the only mode currently supported.') }
      end

    end    

  end
end
